Package: disdat
Type: Package
Title: Data for Comparing Species Distribution Modeling Methods
Version: 1.0-1
Date: 2023-02-07
Maintainer: Roozbeh Valavi <valavi.r@gmail.com>
License: GPL (>= 3)
Encoding: UTF-8
LazyLoad: yes
Depends: R (>= 3.5.0)
Suggests: knitr, rmarkdown, terra, sf, tmap, mapview
VignetteBuilder: knitr
NeedsCompilation: no
Authors@R: c(
	person("Robert J.", "Hijmans", role = "aut",  
			email = "r.hijmans@gmail.com", comment = c(ORCID = "0000-0001-5872-2872")),
    person("Roozbeh", "Valavi", role = c("cre", "aut"), email = "valavi.r@gmail.com"),
    person("Jane", "Elith",  role = "aut", email = "j.elith@gmail.com"))
Description: Easy access to species distribution data for 6 regions in the world, for a total of 226 anonymised species. These data are described and made available by Elith et al (2020) <doi:10.17161/bi.v15i2.13384> to compare species distribution modelling methods. 
Packaged: 2023-02-07 22:04:56 UTC; rvalavi
Author: Robert J. Hijmans [aut] (<https://orcid.org/0000-0001-5872-2872>),
  Roozbeh Valavi [cre, aut],
  Jane Elith [aut]
Repository: CRAN
Date/Publication: 2023-02-07 22:22:34 UTC
Built: R 4.3.3; ; 2025-01-24 06:40:15 UTC; unix
